==> haskell-githash-0.1.4.0-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 githash
version:              0.1.4.0
visibility:           public
id:                   githash-0.1.4.0-6wBdrhHv3MjLBX75YAM6Hs
key:                  githash-0.1.4.0-6wBdrhHv3MjLBX75YAM6Hs
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  141ec36fda72dcda1a7f603eeb20158d
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-8.10.1/site-local/githash-0.1.4.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/githash-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/githash-0.1.4.0
hs-libraries:         HSgithash-0.1.4.0-6wBdrhHv3MjLBX75YAM6Hs
depends:
    base-4.14.0.0 bytestring-0.10.10.0 directory-1.3.6.0
    filepath-1.4.2.1 process-1.6.8.2 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-githash-0.1.4.0-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-githash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 githash
version:              0.1.4.0
visibility:           public
id:                   githash-0.1.4.0-IV23tWZqkEGIXOsZKNbobM
key:                  githash-0.1.4.0-IV23tWZqkEGIXOsZKNbobM
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Adam C. Foltzer
homepage:             https://github.com/snoyberg/githash#readme
synopsis:             Compile git revision info into Haskell projects
description:
    Please see the README and documentation at <https://www.stackage.org/package/githash>

category:             Development
abi:                  e4a594b1286dcbfc68f9bb7b26f1c247
exposed:              True
exposed-modules:      GitHash
hidden-modules:       Paths_githash
import-dirs:          /usr/lib/ghc-8.10.1/site-local/githash-0.1.4.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/githash-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/githash-0.1.4.0
hs-libraries:         HSgithash-0.1.4.0-IV23tWZqkEGIXOsZKNbobM
depends:
    base-4.14.0.0 bytestring-0.10.10.0 directory-1.3.6.0
    filepath-1.4.2.1 process-1.6.8.2 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-githash/html/githash.haddock
haddock-html:         /usr/share/doc/haskell-githash/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
